@@ -1,4 +1,4 @@
-"plot.ltm" <-
+`plot.ltm` <-
 function (x, type = c("ICC", "IIC", "loadings"), items = NULL, z = seq(-3.8, 3.8, length = 100), annot, 
                       labels = NULL, legend = FALSE, cx = "topleft", cy = NULL, ncol = 1, bty = "n", 
                       col = palette(), lty = 1, pch, xlab, ylab, zlab, main, sub = NULL, cex = par("cex"), 
