@@ -1,4 +1,4 @@
-"summary.tpm" <-
+`summary.tpm` <-
 function (object, ...) {
     if (!inherits(object, "tpm"))
         stop("Use only with 'tpm' objects.\n")
